Package: PLPE
Version: 1.71.0
Date: 2009-07-22
Title: Local Pooled Error Test for Differential Expression with Paired
        High-throughput Data
Author: HyungJun Cho <hj4cho@korea.ac.kr> and
            Jae K. Lee <jaeklee@virginia.edu>
Maintainer: Soo-heang Eo <hanansh@korea.ac.kr>
Depends: R (>= 2.6.2), Biobase (>= 2.5.5), LPE, MASS, methods
Description: This package performs tests for paired high-throughput data.
biocViews: Proteomics, Microarray, DifferentialExpression
LazyLoad: yes
LazyData: yes
License: GPL (>= 2)
URL: http://www.korea.ac.kr/~stat2242/
git_url: https://git.bioconductor.org/packages/PLPE
git_branch: devel
git_last_commit: d88d290
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 22:25:42 UTC; biocbuild
